<?php

namespace SM\Factory;

use Doctrine\ORM\EntityManager;
use SM\Traits\TQuery;

class HabilidadePessoalFactory
{
    use TQuery;

    protected $connection;

    protected $entityManager;

    public function __construct(EntityManager $entityManager)
    {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }

    public function getHabilidadePessoal()
    {
        $sql = "SELECT
                    CDHABILITSERV,
                    NMHABILITSERV,
                    NRORG,
                    DTINCLUSAO,
                    DTULTATU,
                    NRORGINCLUSAO,
                    CDOPERINCLUSAO,
                    NRORGULTATU,
                    CDOPERULTATU,
                    IDATIVO
                FROM
                    FCT_HABILITSERV";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }
    
    public function adicionarHabilidadePessoal($params)
    {
        $sql = "INSERT INTO FCT_HABILITSERV (CDHABILITSERV, NMHABILITSERV, NRORG, DTINCLUSAO, NRORGINCLUSAO,
                                        CDOPERINCLUSAO, IDATIVO) 
                        VALUES (:CDHABILITSERV, :NMHABILITSERV, :NRORG, SYSDATE, :NRORG,
                                :CDOPERINCLUSAO, 'S')";

        $this->connection->executeStatement($sql, $params);
    }
    
    public function deleteHabilidadePessoal($params)
    {
        $sql = "DELETE FROM FCT_HABILITSERV
                WHERE CDHABILITSERV = :CDHABILITSERV";

        $this->connection->executeStatement($sql, $params);
    }

    public function saveTabHabilidadePessoal(array $params)
    {
        $sql = "UPDATE FCT_HABILITSERV 
                    SET NMHABILITSERV   = :NMHABILITSERV,
                        NRORG           = :NRORG,
                        DTULTATU        = SYSDATE,
                        NRORGULTATU     = :NRORG,
                        CDOPERULTATU    = :CDOPERULTATU,                
                        IDATIVO         = 'S'
                WHERE CDHABILITSERV = :CDHABILITSERV";
                
        $this->connection->executeStatement($sql, $params);
    }

    public function getHabPessoalTabPessoas($params)
    {
        $sql = "SELECT
                    FCT_RELACHABILIPESSOA.NRRELACHABILIPESSOA,
                    FCT_RELACHABILIPESSOA.CDHABILITSERV,
                    FCT_HABILITSERV.NMHABILITSERV,
                    FCT_RELACHABILIPESSOA.NRPARCNEGOCIO,
                    PARCNEGOCIO.NMPRINCIPALPARC,
                    FCT_RELACHABILIPESSOA.NRORG,
                    FCT_RELACHABILIPESSOA.IDATIVO,
                    FCT_RELACHABILIPESSOA.DTINCLUSAO,
                    FCT_RELACHABILIPESSOA.CDOPERINCLUSAO,
                    FCT_RELACHABILIPESSOA.NRORGINCLUSAO,
                    FCT_RELACHABILIPESSOA.DTULTATU,
                    FCT_RELACHABILIPESSOA.NRORGULTATU,
                    FCT_RELACHABILIPESSOA.CDOPERULTATU
                FROM
                    FCT_RELACHABILIPESSOA LEFT
                    JOIN FCT_HABILITSERV ON FCT_RELACHABILIPESSOA.CDHABILITSERV = FCT_HABILITSERV.CDHABILITSERV
                                            AND FCT_RELACHABILIPESSOA.NRORG = FCT_HABILITSERV.NRORG
                    LEFT JOIN PARCNEGOCIO ON FCT_RELACHABILIPESSOA.NRPARCNEGOCIO = PARCNEGOCIO.NRPARCNEGOCIO
                                            AND FCT_RELACHABILIPESSOA.NRORG = PARCNEGOCIO.NRORG
                WHERE FCT_RELACHABILIPESSOA.CDHABILITSERV = :CDHABILITSERV";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $params);
    }
    
    public function getHabPessoalPessoas($params)
    {
        $sql = "SELECT DISTINCT
                    PARCNEGOCIO.NRPARCNEGOCIO,
                    PARCNEGOCIO.NMPRINCIPALPARC,
                    PARCNEGOCIO.NMSECUNDARIPARC,
                    PARCNEGOCIO.NRINSCRICAOPARC,
                    PARCNEGOCIO.CDTIPOPARCPRINCIPAL,
                    PARCNEGOCIO.NRORG,
                    PARCNEGOCIO.CDTIPOINSCRICAO,
                    /*DECODE(PARCNEGOCIO.IDATIVO, 'S', 'Sim', 'Não') AS IDATIVO,*/
                    PARCNEGOCIO.IDATIVO AS IDATIVO,
                    PARCNEGOCIO.CDOPERRESPONSAVEL,
                    OPERADOR.NMOPERADOR AS NMOPERRESPONSAVEL,
                    PARCNEGOCIO.CDIDIOM,
                    IDIOMA.NMIDIOMA,
                    PARCNEGOCIO.NRMOEDA,
                    FCT_MOEDA.NMMOEDA
                FROM
                    PARCNEGOCIO
                    INNER JOIN PARCERIA ON PARCNEGOCIO.NRPARCNEGOCIO = PARCERIA.NRPARCNEGOCIO
                                        AND PARCNEGOCIO.NRORG = PARCERIA.NRORG
                    LEFT JOIN OPERADOR ON PARCNEGOCIO.CDOPERRESPONSAVEL = OPERADOR.CDOPERADOR
                                        AND PARCNEGOCIO.NRORG = OPERADOR.NRORG
                    LEFT JOIN IDIOMA ON PARCNEGOCIO.CDIDIOM = IDIOMA.CDIDIOM
                    LEFT JOIN FCT_MOEDA ON PARCNEGOCIO.NRMOEDA = FCT_MOEDA.NRMOEDA
                WHERE
                    PARCERIA.CDTIPOPARCEIRO IN (:CDTIPOPARCEIRO) AND PARCNEGOCIO.IDATIVO = :IDATIVO
                    ORDER BY PARCNEGOCIO.NMPRINCIPALPARC ASC";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $params);
    }

    public function saveModalAddPessoa($params)
    {
        $sql = "INSERT INTO FCT_RELACHABILIPESSOA (NRRELACHABILIPESSOA, CDHABILITSERV, NRPARCNEGOCIO, NRORG, DTINCLUSAO, NRORGINCLUSAO,
                                        CDOPERINCLUSAO, IDATIVO) 
                        VALUES (:NRRELACHABILIPESSOA, :CDHABILITSERV, :NRPARCNEGOCIO, :NRORG, SYSDATE, :NRORG,
                                :CDOPERINCLUSAO, 'S')";
        $this->connection->executeStatement($sql, $params);
    }
    
    public function deletePessoas($params)
    {
        $sql = "DELETE FROM FCT_RELACHABILIPESSOA
                WHERE NRRELACHABILIPESSOA = :NRRELACHABILIPESSOA";

        $this->connection->executeStatement($sql, $params);
    }

}