<?php
namespace SM\Service;

use SM\Factory\MapaFaturamentoFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Zeedhi\Framework\DataSource\DataSet;
use SM\Service\FindService;

class MapaFaturamentoService
{

    protected $MapaFaturamentoFactory;
    protected $Environment;
    protected $newCode;
    protected $FindService;

    public function __construct(MapaFaturamentoFactory $MapaFaturamentoFactory, Environment $Environment, NewCode $newCode, FindService $FindService)
    {
        $this->MapaFaturamentoFactory       = $MapaFaturamentoFactory;
        $this->Environment                  = $Environment;
        $this->newCode                      = $newCode;
        $this->FindService                  = $FindService;
    }

    public function getMapaFaturamento($page, $limit, $order, $search, $searchIn, $dynamicFilter)
    {
        $nrorg = $this->Environment->getNrorg();
        
        $dynamicFilter = json_decode(utf8_encode(base64_decode($dynamicFilter)),true);
        
        $parametros = array(
            "TPESTIMADO" => isset($dynamicFilter["TPESTIMADO"][0]) ? $dynamicFilter["TPESTIMADO"][0]['value'] : 'MEDICAO', 
            "NRORG"      => $nrorg
        );
        
        $conditions = $search ? $this->MapaFaturamentoFactory->createSearch($search, $searchIn) : '';
           
        $order = empty($order) ? '' : $this->MapaFaturamentoFactory->createOrderBy($order);

        if(!empty($dynamicFilter["DESVIO_SINAL"][0])){
            $conditions .= $this->createFilterDesvio($dynamicFilter["DESVIO_SINAL"][0], $conditions);
            unset($dynamicFilter["DESVIO_SINAL"]);
        }

        if (!empty($dynamicFilter)) {
            $conditions .= $this->MapaFaturamentoFactory->createDynamicFilter($dynamicFilter, $conditions, false);
        }
        return $this->MapaFaturamentoFactory->getMapaFaturamento($parametros, $page, $limit, $conditions, $order);
    }

    public function getMapaFaturamentoParc($param, $page, $limit, $order, $search, $searchIn, $dynamicFilter)
    {   
        $nrorg = $this->Environment->getNrorg();

        $dynamicFilter = json_decode(utf8_encode(base64_decode($dynamicFilter)),true);

        $parametros = array(
            "TPESTIMADO" => isset($param["TPESTIMADO"]) ? $param["TPESTIMADO"] : 'MEDICAO', 
            "CDSERVORCA" => $param['CDSERVORCA'],
            "NRORG"      => $nrorg
        );

        $conditions = $search ? $this->MapaFaturamentoFactory->createSearch($search, $searchIn) : '';
           
        $order = empty($order) ? '' : $this->MapaFaturamentoFactory->createOrderBy($order);

        if(!empty($dynamicFilter["DESVIO_SINAL"][0])){
            $conditions .= $this->createFilterDesvio($dynamicFilter["DESVIO_SINAL"][0], $conditions);
            unset($dynamicFilter["DESVIO_SINAL"]);
        }

        if (!empty($dynamicFilter)) {
            $conditions .= $this->MapaFaturamentoFactory->createDynamicFilter($dynamicFilter, $conditions, false);
        }

        return $this->MapaFaturamentoFactory->getMapaFaturamentoParc($parametros, $page, $limit, $conditions, $order);
    }

    public function getMapaFaturamentoCli($param, $page, $limit, $order, $search, $searchIn, $dynamicFilter)
    {   
        $nrorg = $this->Environment->getNrorg();

        $dynamicFilter = json_decode(utf8_encode(base64_decode($dynamicFilter)),true);

        $parametros = array(
            "TPESTIMADO"    => isset($param["TPESTIMADO"]) ? $param["TPESTIMADO"] : 'MEDICAO', 
            "CDSERVORCA"    => isset($param['CDSERVORCA']) ? $param['CDSERVORCA'] : null, 
            "NRPARCNEGOCIO" => isset($param['NRPARCNEGOCIO']) ? $param['NRPARCNEGOCIO'] : null,
            "NRORG" => $nrorg
        );

        $conditions = $search ? $this->MapaFaturamentoFactory->createSearch($search, $searchIn) : '';
        
        $order = empty($order) ? '' : $this->MapaFaturamentoFactory->createOrderBy($order);

       if(!empty($dynamicFilter["DESVIO_SINAL"][0])){
            $conditions .= $this->createFilterDesvio($dynamicFilter["DESVIO_SINAL"][0], $conditions);
            unset($dynamicFilter["DESVIO_SINAL"]);
        }

        if (!empty($dynamicFilter)) {
            $conditions .= $this->MapaFaturamentoFactory->createDynamicFilter($dynamicFilter, $conditions, false);
        }

        return $this->MapaFaturamentoFactory->getMapaFaturamentoCli($parametros, $page, $limit, $conditions, $order);
    }

    public function getDadosFaturamentoCompleto($page, $limit, $order, $search, $searchIn, $dynamicFilter)
    {       
        $nrorg = $this->Environment->getNrorg();

        $dynamicFilter = json_decode(utf8_encode(base64_decode($dynamicFilter)),true);

        $parametros = array(
            "TPESTIMADO" => isset($dynamicFilter["TPESTIMADO"][0]) ? $dynamicFilter["TPESTIMADO"][0]['value'] : 'MEDICAO', 
            "NRORG"      => $nrorg
        );

        $conditions = $search ? $this->MapaFaturamentoFactory->createSearch($search, $searchIn) : '';
            
        $order = empty($order) ? '' : $this->MapaFaturamentoFactory->createOrderBy($order);

        if(!empty($dynamicFilter["DESVIO_SINAL"][0])){
            $conditions .= $this->createFilterDesvio($dynamicFilter["DESVIO_SINAL"][0], $conditions);
            unset($dynamicFilter["DESVIO_SINAL"]);
        }

        if (!empty($dynamicFilter)) {
            $conditions .= $this->MapaFaturamentoFactory->createDynamicFilter($dynamicFilter, $conditions, false);
        }

        return $this->MapaFaturamentoFactory->getDadosFaturamentoCompleto($parametros, $page, $limit, $conditions, $order);
    }

    public function createFilterDesvio($desvio, $conditions){
        
        $values = $desvio["value"];
        $arrayfilter = array();

        foreach($values as $value){
            
            if ($value == 'P'){
                $arrayfilter[] = "DESVIO_POSITIVO = 'S'";    
            }
            else if ($value == 'N'){
                $arrayfilter[] = "DESVIO_NEGATIVO = 'S'";   
            }
            else {
                $arrayfilter[] = "DESVIO_ZERADO = 'S'";    
            }

        }
        
        $where = $conditions? 'AND': 'WHERE';

        $stringValues = " $where (" . implode(" OR ",$arrayfilter) . ")";

        return $stringValues;

    }
}
