import { Utilities } from '@/util/Utilities';
import {
    Modal, ModalService, LoadingService, DialogService, Select,
} from '@zeedhi/common';
import { Http, Metadata } from '@zeedhi/core';
import { TekGrid } from '@zeedhi/teknisa-components-common';

export class EscopoFaturamentoTabServicoEscopo {
    private basicModal!: Modal;

    public async exibirModalAddServicoEscopo() {
        this.basicModal = await ModalService.createFromJson('escopoFaturamento/modal/servicoEscopoModalAddServicoEscopo', true);
        this.basicModal.show();
    }

    public fecharModalAddServicoEscopo() {
        this.basicModal.hide();
        this.basicModal?.destroy();
    }

    public async abrirModalAddServicoEscopo() {
        await this.exibirModalAddServicoEscopo();
    }

    public async abrirModalEdicaoIndices() {
        await this.exibirModalAddServicoEscopo();
    }

    public saveModalAddEscFatServicoEscopo() {
        const grid = Metadata.getInstance<TekGrid>('basic-tek-grid-tab-servico-escopo');
        const gridEscopoFaturamento = Metadata.getInstance<TekGrid>('tek-grid-escopo-faturamento_grid');
        const params = {
            NRTIPOORCAMENTO: gridEscopoFaturamento.datasource.currentRow.NRTIPOORCAMENTO,
            NRITESCOPOPROPOSTA: Metadata.getInstance<Select>('formModalAddServicoEscopo-NRITESCOPOPROPOSTA').value,
            CDSERVORCA: Metadata.getInstance<Select>('formModalAddServicoEscopo-CDSERVORCA').value,
            IDPREVCOBRFUT: Metadata.getInstance<Select>('formModalAddServicoEscopo-IDPREVCOBRFUT').value,
        };

        LoadingService.show();
        Http.post('/saveEscFatServicoEscopo', params).then(() => {
            this.fecharModalAddServicoEscopo();
            grid.datasource.get();
            Utilities.showSuccessMessage();
        }).catch((error: any) => {
            if (error.response.data.error === 'EXISTE') {
                Utilities.showDialogMessage('error', 'Operação Bloqueada!', 'Operação Bloqueada. Alguns dos serviços selecionados já estão inseridos.');
            } else {
                Utilities.showErrorMessage(error);
            }
        }).finally(() => {
            LoadingService.hide();
        });
    }

    public editEscFatServicoEscopo() {
        const grid = Metadata.getInstance<TekGrid>('basic-tek-grid-tab-servico-escopo');
        const params = {
            NRITESCOPOPROPOSTA: Metadata.getInstance<Select>('servicosEscopoTab-NRITESCOPOPROPOSTA').value,
            CDSERVORCA: Metadata.getInstance<Select>('servicosEscopoTab-CDSERVORCA').value,
            IDPREVCOBRFUT: Metadata.getInstance<Select>('servicosEscopoTab-IDPREVCOBRFUT').value,
        };

        LoadingService.show();
        Http.post('/saveEscFatServicoEscopo', params).then(() => {
            grid.datasource.get();
            Utilities.showSuccessMessage();
        }).catch((error: any) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            LoadingService.hide();
        });
    }

    public showConfirmDeleteMessageItServicoEscopo({ event }: any) {
        event!.preventDefault();
        DialogService.show({
            name: 'buttons-dialog-operador',
            type: 'warning',
            title: 'Excluir Registro',
            text: 'Deseja realmente excluir todos os registros selecionados?',
            buttons: [
                {
                    name: 'NAO',
                    component: 'ZdButton',
                    label: 'Não',
                    outline: true,
                    events: {
                        click: () => {
                            DialogService.hide();
                        },
                    },
                },
                {
                    name: 'SIM',
                    component: 'ZdButton',
                    label: 'Sim',
                    events: {
                        click: () => {
                            this.deleteEscFatItServicoEscopo();
                            DialogService.hide();
                        },
                    },
                },
            ],
        });
    }

    public deleteEscFatItServicoEscopo() {
        const grid = Metadata.getInstance<TekGrid>('basic-tek-grid-tab-servico-escopo');
        LoadingService.show();
        Http.post('/deleteEscFatItServicoEscopo', grid.selectedRows)
            .then(() => {
                grid.datasource.get();
                Utilities.showSuccessMessage();
            }).catch((error) => {
                Utilities.showErrorMessage(error);
            }).finally(() => {
                LoadingService.hide();
            });
    }
}
